# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n^com/digitalasset/canton/admin/participant/v30/enterprise_participant_replication_service.proto\x12-com.digitalasset.canton.admin.participant.v30\"\x13\n\x11SetPassiveRequest\"\x14\n\x12SetPassiveResponse2\xbd\x01\n\'EnterpriseParticipantReplicationService\x12\x91\x01\n\nSetPassive\x12@.com.digitalasset.canton.admin.participant.v30.SetPassiveRequest\x1a\x41.com.digitalasset.canton.admin.participant.v30.SetPassiveResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.enterprise_participant_replication_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_SETPASSIVEREQUEST']._serialized_start=145
  _globals['_SETPASSIVEREQUEST']._serialized_end=164
  _globals['_SETPASSIVERESPONSE']._serialized_start=166
  _globals['_SETPASSIVERESPONSE']._serialized_end=186
  _globals['_ENTERPRISEPARTICIPANTREPLICATIONSERVICE']._serialized_start=189
  _globals['_ENTERPRISEPARTICIPANTREPLICATIONSERVICE']._serialized_end=378
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/participant_repair_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/admin/participant/v30/participant_repair_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import synchronizer_connectivity_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_synchronizer__connectivity__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/admin/participant/v30/participant_repair_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1aMcom/digitalasset/canton/admin/participant/v30/synchronizer_connectivity.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x01\n\x15PurgeContractsRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\x12!\n\x0c\x63ontract_ids\x18\x02 \x03(\tR\x0b\x63ontractIds\x12\x32\n\x15ignore_already_purged\x18\x03 \x01(\x08R\x13ignoreAlreadyPurged\"\x18\n\x16PurgeContractsResponse\"\xaf\x03\n\x18\x43hangeAssignationRequest\x12:\n\x19source_synchronizer_alias\x18\x01 \x01(\tR\x17sourceSynchronizerAlias\x12:\n\x19target_synchronizer_alias\x18\x02 \x01(\tR\x17targetSynchronizerAlias\x12#\n\rskip_inactive\x18\x03 \x01(\x08R\x0cskipInactive\x12n\n\tcontracts\x18\x04 \x03(\x0b\x32P.com.digitalasset.canton.admin.participant.v30.ChangeAssignationRequest.ContractR\tcontracts\x1a\x85\x01\n\x08\x43ontract\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12G\n\x1dreassignment_counter_override\x18\x02 \x01(\x03H\x00R\x1breassignmentCounterOverride\x88\x01\x01\x42 \n\x1e_reassignment_counter_override\"\x1b\n\x19\x43hangeAssignationResponse\"\x8f\x02\n\x1aMigrateSynchronizerRequest\x12:\n\x19source_synchronizer_alias\x18\x01 \x01(\tR\x17sourceSynchronizerAlias\x12\x9e\x01\n%target_synchronizer_connection_config\x18\x02 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\"targetSynchronizerConnectionConfig\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"\x1d\n\x1bMigrateSynchronizerResponse\"\xa2\x05\n\x13\x45xportAcsOldRequest\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\xa7\x01\n\x1d\x63ontract_synchronizer_renames\x18\x04 \x03(\x0b\x32\x63.com.digitalasset.canton.admin.participant.v30.ExportAcsOldRequest.ContractSynchronizerRenamesEntryR\x1b\x63ontractSynchronizerRenames\x12\x14\n\x05\x66orce\x18\x05 \x01(\x08R\x05\x66orce\x12/\n\x13parties_offboarding\x18\x06 \x01(\x08R\x12partiesOffboarding\x1ah\n\x12TargetSynchronizer\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12)\n\x10protocol_version\x18\x02 \x01(\x05R\x0fprotocolVersion\x1a\xa5\x01\n ContractSynchronizerRenamesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12k\n\x05value\x18\x02 \x01(\x0b\x32U.com.digitalasset.canton.admin.participant.v30.ExportAcsOldRequest.TargetSynchronizerR\x05value:\x02\x38\x01\",\n\x14\x45xportAcsOldResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xba\x01\n\x13ImportAcsOldRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12R\n&allow_contract_id_suffix_recomputation\x18\x03 \x01(\x08R\"allowContractIdSuffixRecomputation\"\xe9\x01\n\x14ImportAcsOldResponse\x12\x8a\x01\n\x13\x63ontract_id_mapping\x18\x01 \x03(\x0b\x32Z.com.digitalasset.canton.admin.participant.v30.ImportAcsOldResponse.ContractIdMappingEntryR\x11\x63ontractIdMapping\x1a\x44\n\x16\x43ontractIdMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xfb\x01\n\x10ImportAcsRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12\x95\x01\n%contract_id_suffix_recomputation_mode\x18\x03 \x01(\x0e\x32\x43.com.digitalasset.canton.admin.participant.v30.ContractIdImportModeR!contractIdSuffixRecomputationMode\"\xe7\x01\n\x11ImportAcsResponse\x12\x8a\x01\n\x14\x63ontract_id_mappings\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.admin.participant.v30.ImportAcsResponse.ContractIdMappingsEntryR\x12\x63ontractIdMappings\x1a\x45\n\x17\x43ontractIdMappingsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"T\n#PurgeDeactivatedSynchronizerRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\"&\n$PurgeDeactivatedSynchronizerResponse\"\x9e\x01\n\x13IgnoreEventsRequest\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x16\n\x14IgnoreEventsResponse\"\xa0\x01\n\x15UnignoreEventsRequest\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12%\n\x0e\x66rom_inclusive\x18\x02 \x01(\x03R\rfromInclusive\x12!\n\x0cto_inclusive\x18\x03 \x01(\x03R\x0btoInclusive\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x18\n\x16UnignoreEventsResponse\"\xaa\x01\n\x1bRollbackUnassignmentRequest\x12\x1f\n\x0bunassign_id\x18\x01 \x01(\tR\nunassignId\x12\x34\n\x16source_synchronizer_id\x18\x02 \x01(\tR\x14sourceSynchronizerId\x12\x34\n\x16target_synchronizer_id\x18\x03 \x01(\tR\x14targetSynchronizerId\"\x1e\n\x1cRollbackUnassignmentResponse*\xb6\x01\n\x14\x43ontractIdImportMode\x12\'\n#CONTRACT_ID_IMPORT_MODE_UNSPECIFIED\x10\x00\x12\"\n\x1e\x43ONTRACT_ID_IMPORT_MODE_ACCEPT\x10\x01\x12&\n\"CONTRACT_ID_IMPORT_MODE_VALIDATION\x10\x02\x12)\n%CONTRACT_ID_IMPORT_MODE_RECOMPUTATION\x10\x03\x32\x93\r\n\x18ParticipantRepairService\x12\x99\x01\n\x0c\x45xportAcsOld\x12\x42.com.digitalasset.canton.admin.participant.v30.ExportAcsOldRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ExportAcsOldResponse0\x01\x12\x99\x01\n\x0cImportAcsOld\x12\x42.com.digitalasset.canton.admin.participant.v30.ImportAcsOldRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ImportAcsOldResponse(\x01\x12\x90\x01\n\tImportAcs\x12?.com.digitalasset.canton.admin.participant.v30.ImportAcsRequest\x1a@.com.digitalasset.canton.admin.participant.v30.ImportAcsResponse(\x01\x12\x9d\x01\n\x0ePurgeContracts\x12\x44.com.digitalasset.canton.admin.participant.v30.PurgeContractsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.PurgeContractsResponse\x12\xac\x01\n\x13MigrateSynchronizer\x12I.com.digitalasset.canton.admin.participant.v30.MigrateSynchronizerRequest\x1aJ.com.digitalasset.canton.admin.participant.v30.MigrateSynchronizerResponse\x12\xa6\x01\n\x11\x43hangeAssignation\x12G.com.digitalasset.canton.admin.participant.v30.ChangeAssignationRequest\x1aH.com.digitalasset.canton.admin.participant.v30.ChangeAssignationResponse\x12\xc7\x01\n\x1cPurgeDeactivatedSynchronizer\x12R.com.digitalasset.canton.admin.participant.v30.PurgeDeactivatedSynchronizerRequest\x1aS.com.digitalasset.canton.admin.participant.v30.PurgeDeactivatedSynchronizerResponse\x12\x97\x01\n\x0cIgnoreEvents\x12\x42.com.digitalasset.canton.admin.participant.v30.IgnoreEventsRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.IgnoreEventsResponse\x12\x9d\x01\n\x0eUnignoreEvents\x12\x44.com.digitalasset.canton.admin.participant.v30.UnignoreEventsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.UnignoreEventsResponse\x12\xaf\x01\n\x14RollbackUnassignment\x12J.com.digitalasset.canton.admin.participant.v30.RollbackUnassignmentRequest\x1aK.com.digitalasset.canton.admin.participant.v30.RollbackUnassignmentResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.participant_repair_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_EXPORTACSOLDREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._loaded_options = None
  _globals['_EXPORTACSOLDREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._loaded_options = None
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._loaded_options = None
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._serialized_options = b'8\001'
  _globals['_CONTRACTIDIMPORTMODE']._serialized_start=3537
  _globals['_CONTRACTIDIMPORTMODE']._serialized_end=3719
  _globals['_PURGECONTRACTSREQUEST']._serialized_start=242
  _globals['_PURGECONTRACTSREQUEST']._serialized_end=399
  _globals['_PURGECONTRACTSRESPONSE']._serialized_start=401
  _globals['_PURGECONTRACTSRESPONSE']._serialized_end=425
  _globals['_CHANGEASSIGNATIONREQUEST']._serialized_start=428
  _globals['_CHANGEASSIGNATIONREQUEST']._serialized_end=859
  _globals['_CHANGEASSIGNATIONREQUEST_CONTRACT']._serialized_start=726
  _globals['_CHANGEASSIGNATIONREQUEST_CONTRACT']._serialized_end=859
  _globals['_CHANGEASSIGNATIONRESPONSE']._serialized_start=861
  _globals['_CHANGEASSIGNATIONRESPONSE']._serialized_end=888
  _globals['_MIGRATESYNCHRONIZERREQUEST']._serialized_start=891
  _globals['_MIGRATESYNCHRONIZERREQUEST']._serialized_end=1162
  _globals['_MIGRATESYNCHRONIZERRESPONSE']._serialized_start=1164
  _globals['_MIGRATESYNCHRONIZERRESPONSE']._serialized_end=1193
  _globals['_EXPORTACSOLDREQUEST']._serialized_start=1196
  _globals['_EXPORTACSOLDREQUEST']._serialized_end=1870
  _globals['_EXPORTACSOLDREQUEST_TARGETSYNCHRONIZER']._serialized_start=1598
  _globals['_EXPORTACSOLDREQUEST_TARGETSYNCHRONIZER']._serialized_end=1702
  _globals['_EXPORTACSOLDREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_start=1705
  _globals['_EXPORTACSOLDREQUEST_CONTRACTSYNCHRONIZERRENAMESENTRY']._serialized_end=1870
  _globals['_EXPORTACSOLDRESPONSE']._serialized_start=1872
  _globals['_EXPORTACSOLDRESPONSE']._serialized_end=1916
  _globals['_IMPORTACSOLDREQUEST']._serialized_start=1919
  _globals['_IMPORTACSOLDREQUEST']._serialized_end=2105
  _globals['_IMPORTACSOLDRESPONSE']._serialized_start=2108
  _globals['_IMPORTACSOLDRESPONSE']._serialized_end=2341
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_start=2273
  _globals['_IMPORTACSOLDRESPONSE_CONTRACTIDMAPPINGENTRY']._serialized_end=2341
  _globals['_IMPORTACSREQUEST']._serialized_start=2344
  _globals['_IMPORTACSREQUEST']._serialized_end=2595
  _globals['_IMPORTACSRESPONSE']._serialized_start=2598
  _globals['_IMPORTACSRESPONSE']._serialized_end=2829
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._serialized_start=2760
  _globals['_IMPORTACSRESPONSE_CONTRACTIDMAPPINGSENTRY']._serialized_end=2829
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERREQUEST']._serialized_start=2831
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERREQUEST']._serialized_end=2915
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERRESPONSE']._serialized_start=2917
  _globals['_PURGEDEACTIVATEDSYNCHRONIZERRESPONSE']._serialized_end=2955
  _globals['_IGNOREEVENTSREQUEST']._serialized_start=2958
  _globals['_IGNOREEVENTSREQUEST']._serialized_end=3116
  _globals['_IGNOREEVENTSRESPONSE']._serialized_start=3118
  _globals['_IGNOREEVENTSRESPONSE']._serialized_end=3140
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_start=3143
  _globals['_UNIGNOREEVENTSREQUEST']._serialized_end=3303
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_start=3305
  _globals['_UNIGNOREEVENTSRESPONSE']._serialized_end=3329
  _globals['_ROLLBACKUNASSIGNMENTREQUEST']._serialized_start=3332
  _globals['_ROLLBACKUNASSIGNMENTREQUEST']._serialized_end=3502
  _globals['_ROLLBACKUNASSIGNMENTRESPONSE']._serialized_start=3504
  _globals['_ROLLBACKUNASSIGNMENTRESPONSE']._serialized_end=3534
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_start=3722
  _globals['_PARTICIPANTREPAIRSERVICE']._serialized_end=5405
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="CreateAndExerciseCommand")


@_attrs_define
class CreateAndExerciseCommand:
    """Create a contract and exercise a choice on it in the same transaction.

    Attributes:
        template_id (str): The template of the contract the client wants to create.
            Both package-name and package-id reference identifier formats for the template-id are supported.
            Note: The package-id reference identifier format is deprecated. We plan to end support for this format in
            version 3.4.

            Required
        create_arguments (Any): The arguments required for creating a contract from this template.
            Required
        choice (str): The name of the choice the client wants to exercise.
            Must be a valid NameString (as described in ``value.proto``).
            Required
        choice_argument (Any): The argument for this choice.
            Required
    """

    template_id: str
    create_arguments: Any
    choice: str
    choice_argument: Any
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        template_id = self.template_id

        create_arguments = self.create_arguments

        choice = self.choice

        choice_argument = self.choice_argument

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "templateId": template_id,
                "createArguments": create_arguments,
                "choice": choice,
                "choiceArgument": choice_argument,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        template_id = d.pop("templateId")

        create_arguments = d.pop("createArguments")

        choice = d.pop("choice")

        choice_argument = d.pop("choiceArgument")

        create_and_exercise_command = cls(
            template_id=template_id,
            create_arguments=create_arguments,
            choice=choice,
            choice_argument=choice_argument,
        )

        create_and_exercise_command.additional_properties = d
        return create_and_exercise_command

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/daml_lf_2_1/daml_lf2.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/daml/daml_lf_2_1/daml_lf2.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#com/daml/daml_lf_2_1/daml_lf2.proto\x12\x0b\x64\x61ml_lf_2_1\"\x06\n\x04Unit\"u\n\nPackageRef\x12\'\n\x04self\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.UnitH\x00R\x04self\x12\x37\n\x17package_id_interned_str\x18\x03 \x01(\x05H\x00R\x14packageIdInternedStrB\x05\n\x03Sum\"\x82\x01\n\tModuleRef\x12\x38\n\x0bpackage_ref\x18\x01 \x01(\x0b\x32\x17.daml_lf_2_1.PackageRefR\npackageRef\x12;\n\x1amodule_name_interned_dname\x18\x02 \x01(\x05R\x17moduleNameInternedDname\"m\n\x0bTypeConName\x12.\n\x06module\x18\x01 \x01(\x0b\x32\x16.daml_lf_2_1.ModuleRefR\x06module\x12.\n\x13name_interned_dname\x18\x02 \x01(\x05R\x11nameInternedDname\"m\n\x0bTypeSynName\x12.\n\x06module\x18\x01 \x01(\x0b\x32\x16.daml_lf_2_1.ModuleRefR\x06module\x12.\n\x13name_interned_dname\x18\x02 \x01(\x05R\x11nameInternedDname\"i\n\x07ValName\x12.\n\x06module\x18\x01 \x01(\x0b\x32\x16.daml_lf_2_1.ModuleRefR\x06module\x12.\n\x13name_interned_dname\x18\x02 \x01(\x05R\x11nameInternedDname\"d\n\rFieldWithType\x12,\n\x12\x66ield_interned_str\x18\x03 \x01(\x05R\x10\x66ieldInternedStr\x12%\n\x04type\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\"^\n\x0bVarWithType\x12(\n\x10var_interned_str\x18\x03 \x01(\x05R\x0evarInternedStr\x12%\n\x04type\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\"b\n\x0fTypeVarWithKind\x12(\n\x10var_interned_str\x18\x03 \x01(\x05R\x0evarInternedStr\x12%\n\x04kind\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.KindR\x04kind\"d\n\rFieldWithExpr\x12,\n\x12\x66ield_interned_str\x18\x03 \x01(\x05R\x10\x66ieldInternedStr\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\"d\n\x07\x42inding\x12\x30\n\x06\x62inder\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.VarWithTypeR\x06\x62inder\x12\'\n\x05\x62ound\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x05\x62ound\"\xed\x01\n\x04Kind\x12\'\n\x04star\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.UnitH\x00R\x04star\x12/\n\x05\x61rrow\x18\x02 \x01(\x0b\x32\x17.daml_lf_2_1.Kind.ArrowH\x00R\x05\x61rrow\x12%\n\x03nat\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.UnitH\x00R\x03nat\x1a]\n\x05\x41rrow\x12)\n\x06params\x18\x01 \x03(\x0b\x32\x11.daml_lf_2_1.KindR\x06params\x12)\n\x06result\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.KindR\x06resultB\x05\n\x03Sum\"\xfa\x06\n\x04Type\x12)\n\x03var\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.Type.VarH\x00R\x03var\x12)\n\x03\x63on\x18\x02 \x01(\x0b\x32\x15.daml_lf_2_1.Type.ConH\x00R\x03\x63on\x12\x35\n\x07\x62uiltin\x18\x03 \x01(\x0b\x32\x19.daml_lf_2_1.Type.BuiltinH\x00R\x07\x62uiltin\x12\x32\n\x06\x66orall\x18\x04 \x01(\x0b\x32\x18.daml_lf_2_1.Type.ForallH\x00R\x06\x66orall\x12\x32\n\x06struct\x18\x05 \x01(\x0b\x32\x18.daml_lf_2_1.Type.StructH\x00R\x06struct\x12\x12\n\x03nat\x18\x06 \x01(\x12H\x00R\x03nat\x12)\n\x03syn\x18\x07 \x01(\x0b\x32\x15.daml_lf_2_1.Type.SynH\x00R\x03syn\x12\x1c\n\x08interned\x18\x08 \x01(\x05H\x00R\x08interned\x1aV\n\x03Var\x12(\n\x10var_interned_str\x18\x03 \x01(\x05R\x0evarInternedStr\x12%\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x11.daml_lf_2_1.TypeR\x04\x61rgs\x1a\\\n\x03\x43on\x12.\n\x05tycon\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x05tycon\x12%\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x11.daml_lf_2_1.TypeR\x04\x61rgs\x1a\\\n\x03Syn\x12.\n\x05tysyn\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeSynNameR\x05tysyn\x12%\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x11.daml_lf_2_1.TypeR\x04\x61rgs\x1a\x64\n\x07\x42uiltin\x12\x32\n\x07\x62uiltin\x18\x01 \x01(\x0e\x32\x18.daml_lf_2_1.BuiltinTypeR\x07\x62uiltin\x12%\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x11.daml_lf_2_1.TypeR\x04\x61rgs\x1a\x61\n\x06\x46orall\x12\x30\n\x04vars\x18\x01 \x03(\x0b\x32\x1c.daml_lf_2_1.TypeVarWithKindR\x04vars\x12%\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04\x62ody\x1a<\n\x06Struct\x12\x32\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x1a.daml_lf_2_1.FieldWithTypeR\x06\x66ieldsB\x05\n\x03Sum\"\x87\x03\n\nBuiltinLit\x12\x16\n\x05int64\x18\x01 \x01(\x12H\x00R\x05int64\x12\x1e\n\ttimestamp\x18\x02 \x01(\x10H\x00R\ttimestamp\x12\x32\n\x14numeric_interned_str\x18\x03 \x01(\x05H\x00R\x12numericInternedStr\x12,\n\x11text_interned_str\x18\x04 \x01(\x05H\x00R\x0ftextInternedStr\x12\x14\n\x04\x64\x61te\x18\x05 \x01(\x05H\x00R\x04\x64\x61te\x12L\n\rrounding_mode\x18\xe9\x07 \x01(\x0e\x32$.daml_lf_2_1.BuiltinLit.RoundingModeH\x00R\x0croundingMode\"t\n\x0cRoundingMode\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\x0b\n\x07\x43\x45ILING\x10\x02\x12\t\n\x05\x46LOOR\x10\x03\x12\x0b\n\x07HALF_UP\x10\x04\x12\r\n\tHALF_DOWN\x10\x05\x12\r\n\tHALF_EVEN\x10\x06\x12\x0f\n\x0bUNNECESSARY\x10\x07\x42\x05\n\x03Sum\"\xe6\x01\n\x08Location\x12.\n\x06module\x18\x01 \x01(\x0b\x32\x16.daml_lf_2_1.ModuleRefR\x06module\x12\x31\n\x05range\x18\x02 \x01(\x0b\x32\x1b.daml_lf_2_1.Location.RangeR\x05range\x1aw\n\x05Range\x12\x1d\n\nstart_line\x18\x01 \x01(\x05R\tstartLine\x12\x1b\n\tstart_col\x18\x02 \x01(\x05R\x08startCol\x12\x19\n\x08\x65nd_line\x18\x03 \x01(\x05R\x07\x65ndLine\x12\x17\n\x07\x65nd_col\x18\x04 \x01(\x05R\x06\x65ndCol\"\xac=\n\x04\x45xpr\x12\x31\n\x08location\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.LocationR\x08location\x12*\n\x10var_interned_str\x18\x02 \x01(\x05H\x00R\x0evarInternedStr\x12(\n\x03val\x18\x03 \x01(\x0b\x32\x14.daml_lf_2_1.ValNameH\x00R\x03val\x12\x38\n\x07\x62uiltin\x18\x04 \x01(\x0e\x32\x1c.daml_lf_2_1.BuiltinFunctionH\x00R\x07\x62uiltin\x12:\n\x0b\x62uiltin_con\x18\x05 \x01(\x0e\x32\x17.daml_lf_2_1.BuiltinConH\x00R\nbuiltinCon\x12:\n\x0b\x62uiltin_lit\x18\x06 \x01(\x0b\x32\x17.daml_lf_2_1.BuiltinLitH\x00R\nbuiltinLit\x12\x33\n\x07rec_con\x18\x07 \x01(\x0b\x32\x18.daml_lf_2_1.Expr.RecConH\x00R\x06recCon\x12\x36\n\x08rec_proj\x18\x08 \x01(\x0b\x32\x19.daml_lf_2_1.Expr.RecProjH\x00R\x07recProj\x12\x33\n\x07rec_upd\x18\t \x01(\x0b\x32\x18.daml_lf_2_1.Expr.RecUpdH\x00R\x06recUpd\x12?\n\x0bvariant_con\x18\n \x01(\x0b\x32\x1c.daml_lf_2_1.Expr.VariantConH\x00R\nvariantCon\x12\x36\n\x08\x65num_con\x18\x0b \x01(\x0b\x32\x19.daml_lf_2_1.Expr.EnumConH\x00R\x07\x65numCon\x12<\n\nstruct_con\x18\x0c \x01(\x0b\x32\x1b.daml_lf_2_1.Expr.StructConH\x00R\tstructCon\x12?\n\x0bstruct_proj\x18\r \x01(\x0b\x32\x1c.daml_lf_2_1.Expr.StructProjH\x00R\nstructProj\x12<\n\nstruct_upd\x18\x0e \x01(\x0b\x32\x1b.daml_lf_2_1.Expr.StructUpdH\x00R\tstructUpd\x12)\n\x03\x61pp\x18\x0f \x01(\x0b\x32\x15.daml_lf_2_1.Expr.AppH\x00R\x03\x61pp\x12\x30\n\x06ty_app\x18\x10 \x01(\x0b\x32\x17.daml_lf_2_1.Expr.TyAppH\x00R\x05tyApp\x12)\n\x03\x61\x62s\x18\x11 \x01(\x0b\x32\x15.daml_lf_2_1.Expr.AbsH\x00R\x03\x61\x62s\x12\x30\n\x06ty_abs\x18\x12 \x01(\x0b\x32\x17.daml_lf_2_1.Expr.TyAbsH\x00R\x05tyAbs\x12\'\n\x04\x63\x61se\x18\x13 \x01(\x0b\x32\x11.daml_lf_2_1.CaseH\x00R\x04\x63\x61se\x12&\n\x03let\x18\x14 \x01(\x0b\x32\x12.daml_lf_2_1.BlockH\x00R\x03let\x12)\n\x03nil\x18\x15 \x01(\x0b\x32\x15.daml_lf_2_1.Expr.NilH\x00R\x03nil\x12,\n\x04\x63ons\x18\x16 \x01(\x0b\x32\x16.daml_lf_2_1.Expr.ConsH\x00R\x04\x63ons\x12-\n\x06update\x18\x17 \x01(\x0b\x32\x13.daml_lf_2_1.UpdateH\x00R\x06update\x12\x45\n\roptional_none\x18\x19 \x01(\x0b\x32\x1e.daml_lf_2_1.Expr.OptionalNoneH\x00R\x0coptionalNone\x12\x45\n\roptional_some\x18\x1a \x01(\x0b\x32\x1e.daml_lf_2_1.Expr.OptionalSomeH\x00R\x0coptionalSome\x12\x30\n\x06to_any\x18\x1b \x01(\x0b\x32\x17.daml_lf_2_1.Expr.ToAnyH\x00R\x05toAny\x12\x36\n\x08\x66rom_any\x18\x1c \x01(\x0b\x32\x19.daml_lf_2_1.Expr.FromAnyH\x00R\x07\x66romAny\x12.\n\x08type_rep\x18\x1d \x01(\x0b\x32\x11.daml_lf_2_1.TypeH\x00R\x07typeRep\x12L\n\x10to_any_exception\x18\x1e \x01(\x0b\x32 .daml_lf_2_1.Expr.ToAnyExceptionH\x00R\x0etoAnyException\x12R\n\x12\x66rom_any_exception\x18\x1f \x01(\x0b\x32\".daml_lf_2_1.Expr.FromAnyExceptionH\x00R\x10\x66romAnyException\x12/\n\x05throw\x18  \x01(\x0b\x32\x17.daml_lf_2_1.Expr.ThrowH\x00R\x05throw\x12\x42\n\x0cto_interface\x18! \x01(\x0b\x32\x1d.daml_lf_2_1.Expr.ToInterfaceH\x00R\x0btoInterface\x12H\n\x0e\x66rom_interface\x18\" \x01(\x0b\x32\x1f.daml_lf_2_1.Expr.FromInterfaceH\x00R\rfromInterface\x12H\n\x0e\x63\x61ll_interface\x18# \x01(\x0b\x32\x1f.daml_lf_2_1.Expr.CallInterfaceH\x00R\rcallInterface\x12W\n\x13signatory_interface\x18$ \x01(\x0b\x32$.daml_lf_2_1.Expr.SignatoryInterfaceH\x00R\x12signatoryInterface\x12T\n\x12observer_interface\x18% \x01(\x0b\x32#.daml_lf_2_1.Expr.ObserverInterfaceH\x00R\x11observerInterface\x12H\n\x0eview_interface\x18& \x01(\x0b\x32\x1f.daml_lf_2_1.Expr.ViewInterfaceH\x00R\rviewInterface\x12[\n\x15unsafe_from_interface\x18\' \x01(\x0b\x32%.daml_lf_2_1.Expr.UnsafeFromInterfaceH\x00R\x13unsafeFromInterface\x12k\n\x1binterface_template_type_rep\x18( \x01(\x0b\x32*.daml_lf_2_1.Expr.InterfaceTemplateTypeRepH\x00R\x18interfaceTemplateTypeRep\x12[\n\x15to_required_interface\x18) \x01(\x0b\x32%.daml_lf_2_1.Expr.ToRequiredInterfaceH\x00R\x13toRequiredInterface\x12\x61\n\x17\x66rom_required_interface\x18* \x01(\x0b\x32\'.daml_lf_2_1.Expr.FromRequiredInterfaceH\x00R\x15\x66romRequiredInterface\x12t\n\x1eunsafe_from_required_interface\x18+ \x01(\x0b\x32-.daml_lf_2_1.Expr.UnsafeFromRequiredInterfaceH\x00R\x1bunsafeFromRequiredInterface\x12R\n\x11\x63hoice_controller\x18\xe9\x07 \x01(\x0b\x32\".daml_lf_2_1.Expr.ChoiceControllerH\x00R\x10\x63hoiceController\x12L\n\x0f\x63hoice_observer\x18\xea\x07 \x01(\x0b\x32 .daml_lf_2_1.Expr.ChoiceObserverH\x00R\x0e\x63hoiceObserver\x12\x34\n\x08scenario\x18\xeb\x07 \x01(\x0b\x32\x15.daml_lf_2_1.ScenarioH\x00R\x08scenario\x12\x45\n\x0c\x65xperimental\x18\x8fN \x01(\x0b\x32\x1e.daml_lf_2_1.Expr.ExperimentalH\x00R\x0c\x65xperimental\x1ai\n\x06RecCon\x12+\n\x05tycon\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.Type.ConR\x05tycon\x12\x32\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x1a.daml_lf_2_1.FieldWithExprR\x06\x66ields\x1a\x8f\x01\n\x07RecProj\x12+\n\x05tycon\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.Type.ConR\x05tycon\x12,\n\x12\x66ield_interned_str\x18\x04 \x01(\x05R\x10\x66ieldInternedStr\x12)\n\x06record\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x06record\x1a\xb9\x01\n\x06RecUpd\x12+\n\x05tycon\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.Type.ConR\x05tycon\x12,\n\x12\x66ield_interned_str\x18\x02 \x01(\x05R\x10\x66ieldInternedStr\x12)\n\x06record\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x06record\x12)\n\x06update\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x06update\x1a\xa6\x01\n\nVariantCon\x12+\n\x05tycon\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.Type.ConR\x05tycon\x12\x37\n\x18variant_con_interned_str\x18\x02 \x01(\x05R\x15variantConInternedStr\x12\x32\n\x0bvariant_arg\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\nvariantArg\x1al\n\x07\x45numCon\x12.\n\x05tycon\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x05tycon\x12\x31\n\x15\x65num_con_interned_str\x18\x02 \x01(\x05R\x12\x65numConInternedStr\x1a?\n\tStructCon\x12\x32\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x1a.daml_lf_2_1.FieldWithExprR\x06\x66ields\x1a\x65\n\nStructProj\x12,\n\x12\x66ield_interned_str\x18\x01 \x01(\x05R\x10\x66ieldInternedStr\x12)\n\x06struct\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x06struct\x1a\x8f\x01\n\tStructUpd\x12,\n\x12\x66ield_interned_str\x18\x01 \x01(\x05R\x10\x66ieldInternedStr\x12)\n\x06struct\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x06struct\x12)\n\x06update\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x06update\x1aQ\n\x03\x41pp\x12#\n\x03\x66un\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x66un\x12%\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x61rgs\x1aW\n\x05TyApp\x12%\n\x04\x65xpr\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x12\'\n\x05types\x18\x02 \x03(\x0b\x32\x11.daml_lf_2_1.TypeR\x05types\x1a\\\n\x03\x41\x62s\x12.\n\x05param\x18\x01 \x03(\x0b\x32\x18.daml_lf_2_1.VarWithTypeR\x05param\x12%\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x62ody\x1a\x62\n\x05TyAbs\x12\x32\n\x05param\x18\x01 \x03(\x0b\x32\x1c.daml_lf_2_1.TypeVarWithKindR\x05param\x12%\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x62ody\x1a,\n\x03Nil\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x1a}\n\x04\x43ons\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x12\'\n\x05\x66ront\x18\x02 \x03(\x0b\x32\x11.daml_lf_2_1.ExprR\x05\x66ront\x12%\n\x04tail\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04tail\x1a\x35\n\x0cOptionalNone\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x1a^\n\x0cOptionalSome\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x05value\x1aU\n\x05ToAny\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1aW\n\x07\x46romAny\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1a^\n\x0eToAnyException\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1a`\n\x10\x46romAnyException\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1a\xaf\x01\n\x05Throw\x12\x32\n\x0breturn_type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\nreturnType\x12\x38\n\x0e\x65xception_type\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\rexceptionType\x12\x38\n\x0e\x65xception_expr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\rexceptionExpr\x1a\xc5\x01\n\x0bToInterface\x12?\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\rinterfaceType\x12=\n\rtemplate_type\x18\x02 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x0ctemplateType\x12\x36\n\rtemplate_expr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x0ctemplateExpr\x1a\xc9\x01\n\rFromInterface\x12?\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\rinterfaceType\x12=\n\rtemplate_type\x18\x02 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x0ctemplateType\x12\x38\n\x0einterface_expr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\rinterfaceExpr\x1a\xbc\x01\n\rCallInterface\x12?\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\rinterfaceType\x12\x30\n\x14method_interned_name\x18\x02 \x01(\x05R\x12methodInternedName\x12\x38\n\x0einterface_expr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\rinterfaceExpr\x1an\n\rViewInterface\x12\x36\n\tinterface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\tinterface\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1as\n\x12SignatoryInterface\x12\x36\n\tinterface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\tinterface\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1ar\n\x11ObserverInterface\x12\x36\n\tinterface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\tinterface\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1a\x8c\x02\n\x13UnsafeFromInterface\x12?\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\rinterfaceType\x12=\n\rtemplate_type\x18\x02 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x0ctemplateType\x12;\n\x10\x63ontract_id_expr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x0e\x63ontractIdExpr\x12\x38\n\x0einterface_expr\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\rinterfaceExpr\x1a\xd0\x01\n\x13ToRequiredInterface\x12G\n\x12required_interface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x11requiredInterface\x12I\n\x13requiring_interface\x18\x02 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x12requiringInterface\x12%\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1a\xd2\x01\n\x15\x46romRequiredInterface\x12G\n\x12required_interface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x11requiredInterface\x12I\n\x13requiring_interface\x18\x02 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x12requiringInterface\x12%\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1a\xa8\x02\n\x1bUnsafeFromRequiredInterface\x12G\n\x12required_interface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x11requiredInterface\x12I\n\x13requiring_interface\x18\x02 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x12requiringInterface\x12;\n\x10\x63ontract_id_expr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x0e\x63ontractIdExpr\x12\x38\n\x0einterface_expr\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\rinterfaceExpr\x1ay\n\x18InterfaceTemplateTypeRep\x12\x36\n\tinterface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\tinterface\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1a\xeb\x01\n\x10\x43hoiceController\x12\x34\n\x08template\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12\x36\n\rcontract_expr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x0c\x63ontractExpr\x12\x39\n\x0f\x63hoice_arg_expr\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\rchoiceArgExpr\x1a\xe9\x01\n\x0e\x43hoiceObserver\x12\x34\n\x08template\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12\x36\n\rcontract_expr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x0c\x63ontractExpr\x12\x39\n\x0f\x63hoice_arg_expr\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\rchoiceArgExpr\x1aI\n\x0c\x45xperimental\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x04type\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04typeB\x05\n\x03Sum\"\xa2\x07\n\x07\x43\x61seAlt\x12-\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.UnitH\x00R\x07\x64\x65\x66\x61ult\x12\x38\n\x07variant\x18\x03 \x01(\x0b\x32\x1c.daml_lf_2_1.CaseAlt.VariantH\x00R\x07variant\x12:\n\x0b\x62uiltin_con\x18\x04 \x01(\x0e\x32\x17.daml_lf_2_1.BuiltinConH\x00R\nbuiltinCon\x12%\n\x03nil\x18\x05 \x01(\x0b\x32\x11.daml_lf_2_1.UnitH\x00R\x03nil\x12/\n\x04\x63ons\x18\x06 \x01(\x0b\x32\x19.daml_lf_2_1.CaseAlt.ConsH\x00R\x04\x63ons\x12\x38\n\roptional_none\x18\x07 \x01(\x0b\x32\x11.daml_lf_2_1.UnitH\x00R\x0coptionalNone\x12H\n\roptional_some\x18\x08 \x01(\x0b\x32!.daml_lf_2_1.CaseAlt.OptionalSomeH\x00R\x0coptionalSome\x12/\n\x04\x65num\x18\t \x01(\x0b\x32\x19.daml_lf_2_1.CaseAlt.EnumH\x00R\x04\x65num\x12%\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x62ody\x1a\x97\x01\n\x07Variant\x12*\n\x03\x63on\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x03\x63on\x12\x30\n\x14variant_interned_str\x18\x02 \x01(\x05R\x12variantInternedStr\x12.\n\x13\x62inder_interned_str\x18\x03 \x01(\x05R\x11\x62inderInternedStr\x1al\n\x04\x45num\x12*\n\x03\x63on\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x03\x63on\x12\x38\n\x18\x63onstructor_interned_str\x18\x02 \x01(\x05R\x16\x63onstructorInternedStr\x1al\n\x04\x43ons\x12\x31\n\x15var_head_interned_str\x18\x01 \x01(\x05R\x12varHeadInternedStr\x12\x31\n\x15var_tail_interned_str\x18\x02 \x01(\x05R\x12varTailInternedStr\x1a\x41\n\x0cOptionalSome\x12\x31\n\x15var_body_interned_str\x18\x01 \x01(\x05R\x12varBodyInternedStrB\x05\n\x03Sum\"Y\n\x04\x43\x61se\x12\'\n\x05scrut\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x05scrut\x12(\n\x04\x61lts\x18\x02 \x03(\x0b\x32\x14.daml_lf_2_1.CaseAltR\x04\x61lts\"`\n\x05\x42lock\x12\x30\n\x08\x62indings\x18\x01 \x03(\x0b\x32\x14.daml_lf_2_1.BindingR\x08\x62indings\x12%\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x62ody\"T\n\x04Pure\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\"\x8b\x18\n\x06Update\x12\'\n\x04pure\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.PureH\x00R\x04pure\x12*\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x12.daml_lf_2_1.BlockH\x00R\x05\x62lock\x12\x34\n\x06\x63reate\x18\x03 \x01(\x0b\x32\x1a.daml_lf_2_1.Update.CreateH\x00R\x06\x63reate\x12:\n\x08\x65xercise\x18\x04 \x01(\x0b\x32\x1c.daml_lf_2_1.Update.ExerciseH\x00R\x08\x65xercise\x12K\n\x0f\x65xercise_by_key\x18\n \x01(\x0b\x32!.daml_lf_2_1.Update.ExerciseByKeyH\x00R\rexerciseByKey\x12\x31\n\x05\x66\x65tch\x18\x05 \x01(\x0b\x32\x19.daml_lf_2_1.Update.FetchH\x00R\x05\x66\x65tch\x12.\n\x08get_time\x18\x06 \x01(\x0b\x32\x11.daml_lf_2_1.UnitH\x00R\x07getTime\x12G\n\rlookup_by_key\x18\x08 \x01(\x0b\x32!.daml_lf_2_1.Update.RetrieveByKeyH\x00R\x0blookupByKey\x12\x45\n\x0c\x66\x65tch_by_key\x18\t \x01(\x0b\x32!.daml_lf_2_1.Update.RetrieveByKeyH\x00R\nfetchByKey\x12>\n\nembed_expr\x18\x07 \x01(\x0b\x32\x1d.daml_lf_2_1.Update.EmbedExprH\x00R\tembedExpr\x12;\n\ttry_catch\x18\x0b \x01(\x0b\x32\x1c.daml_lf_2_1.Update.TryCatchH\x00R\x08tryCatch\x12P\n\x10\x63reate_interface\x18\x0c \x01(\x0b\x32#.daml_lf_2_1.Update.CreateInterfaceH\x00R\x0f\x63reateInterface\x12V\n\x12\x65xercise_interface\x18\r \x01(\x0b\x32%.daml_lf_2_1.Update.ExerciseInterfaceH\x00R\x11\x65xerciseInterface\x12M\n\x0f\x66\x65tch_interface\x18\x0e \x01(\x0b\x32\".daml_lf_2_1.Update.FetchInterfaceH\x00R\x0e\x66\x65tchInterface\x12Q\n\x10\x64ynamic_exercise\x18\xe9\x07 \x01(\x0b\x32#.daml_lf_2_1.Update.DynamicExerciseH\x00R\x0f\x64ynamicExercise\x12?\n\nsoft_fetch\x18\xea\x07 \x01(\x0b\x32\x1d.daml_lf_2_1.Update.SoftFetchH\x00R\tsoftFetch\x12H\n\rsoft_exercise\x18\xeb\x07 \x01(\x0b\x32 .daml_lf_2_1.Update.SoftExerciseH\x00R\x0csoftExercise\x1a\x65\n\x06\x43reate\x12\x34\n\x08template\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08template\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1ap\n\x0f\x43reateInterface\x12\x36\n\tinterface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\tinterface\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x1a\xc0\x01\n\x08\x45xercise\x12\x34\n\x08template\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x06 \x01(\x05R\x11\x63hoiceInternedStr\x12#\n\x03\x63id\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x63id\x12#\n\x03\x61rg\x18\x05 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x61rgJ\x04\x08\x04\x10\x05\x1a\xbe\x01\n\x0cSoftExercise\x12\x34\n\x08template\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12#\n\x03\x63id\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x63id\x12#\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x61rg\x1a\xc1\x01\n\x0f\x44ynamicExercise\x12\x34\n\x08template\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12#\n\x03\x63id\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x63id\x12#\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x61rg\x1a\xee\x01\n\x11\x45xerciseInterface\x12\x36\n\tinterface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\tinterface\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12#\n\x03\x63id\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x63id\x12#\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x61rg\x12\'\n\x05guard\x18\x05 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x05guard\x1a\xbf\x01\n\rExerciseByKey\x12\x34\n\x08template\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12#\n\x03key\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03key\x12#\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x61rg\x1a\x62\n\x05\x46\x65tch\x12\x34\n\x08template\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08template\x12#\n\x03\x63id\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x63id\x1a\x66\n\tSoftFetch\x12\x34\n\x08template\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08template\x12#\n\x03\x63id\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x63id\x1am\n\x0e\x46\x65tchInterface\x12\x36\n\tinterface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\tinterface\x12#\n\x03\x63id\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03\x63id\x1aY\n\tEmbedExpr\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x12%\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x62ody\x1aj\n\rRetrieveByKey\x12\x34\n\x08template\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08template\x12#\n\x03key\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x03key\x1a\xc8\x01\n\x08TryCatch\x12\x32\n\x0breturn_type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\nreturnType\x12,\n\x08try_expr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x07tryExpr\x12(\n\x10var_interned_str\x18\x03 \x01(\x05R\x0evarInternedStr\x12\x30\n\ncatch_expr\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\tcatchExprB\x05\n\x03Sum\"\x8f\x05\n\x08Scenario\x12\'\n\x04pure\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.PureH\x00R\x04pure\x12*\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x12.daml_lf_2_1.BlockH\x00R\x05\x62lock\x12\x36\n\x06\x63ommit\x18\x03 \x01(\x0b\x32\x1c.daml_lf_2_1.Scenario.CommitH\x00R\x06\x63ommit\x12>\n\nmustFailAt\x18\x04 \x01(\x0b\x32\x1c.daml_lf_2_1.Scenario.CommitH\x00R\nmustFailAt\x12\'\n\x04pass\x18\x05 \x01(\x0b\x32\x11.daml_lf_2_1.ExprH\x00R\x04pass\x12.\n\x08get_time\x18\x06 \x01(\x0b\x32\x11.daml_lf_2_1.UnitH\x00R\x07getTime\x12\x30\n\tget_party\x18\x07 \x01(\x0b\x32\x11.daml_lf_2_1.ExprH\x00R\x08getParty\x12@\n\nembed_expr\x18\x08 \x01(\x0b\x32\x1f.daml_lf_2_1.Scenario.EmbedExprH\x00R\tembedExpr\x1a\x86\x01\n\x06\x43ommit\x12\'\n\x05party\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x05party\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x12,\n\x08ret_type\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x07retType\x1aY\n\tEmbedExpr\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x12%\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x62odyB\x05\n\x03Sum\"\xf4\x03\n\x0eTemplateChoice\x12\x31\n\x08location\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.LocationR\x08location\x12*\n\x11name_interned_str\x18\x02 \x01(\x05R\x0fnameInternedStr\x12\x1c\n\tconsuming\x18\x03 \x01(\x08R\tconsuming\x12\x33\n\x0b\x63ontrollers\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x0b\x63ontrollers\x12/\n\tobservers\x18\x05 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\tobservers\x12\x37\n\narg_binder\x18\x06 \x01(\x0b\x32\x18.daml_lf_2_1.VarWithTypeR\targBinder\x12,\n\x08ret_type\x18\x08 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x07retType\x12)\n\x06update\x18\t \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x06update\x12\x37\n\x18self_binder_interned_str\x18\n \x01(\x05R\x15selfBinderInternedStr\x12\x34\n\x0b\x61uthorizers\x18\xe9\x07 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x0b\x61uthorizers\"\x8a\x02\n\x15InterfaceInstanceBody\x12T\n\x07methods\x18\x01 \x03(\x0b\x32:.daml_lf_2_1.InterfaceInstanceBody.InterfaceInstanceMethodR\x07methods\x12%\n\x04view\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04view\x1at\n\x17InterfaceInstanceMethod\x12\x30\n\x14method_interned_name\x18\x01 \x01(\x05R\x12methodInternedName\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x05value\"\xda\x06\n\x0b\x44\x65\x66Template\x12\x30\n\x14tycon_interned_dname\x18\x01 \x01(\x05R\x12tyconInternedDname\x12,\n\x12param_interned_str\x18\x02 \x01(\x05R\x10paramInternedStr\x12+\n\x07precond\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x07precond\x12\x33\n\x0bsignatories\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x0bsignatories\x12/\n\tagreement\x18\x05 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\tagreement\x12\x35\n\x07\x63hoices\x18\x06 \x03(\x0b\x32\x1b.daml_lf_2_1.TemplateChoiceR\x07\x63hoices\x12/\n\tobservers\x18\x07 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\tobservers\x12\x31\n\x08location\x18\x08 \x01(\x0b\x32\x15.daml_lf_2_1.LocationR\x08location\x12\x31\n\x03key\x18\t \x01(\x0b\x32\x1f.daml_lf_2_1.DefTemplate.DefKeyR\x03key\x12\x43\n\nimplements\x18\n \x03(\x0b\x32#.daml_lf_2_1.DefTemplate.ImplementsR\nimplements\x1a\x92\x01\n\x06\x44\x65\x66Key\x12%\n\x04type\x18\x01 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\x12,\n\x08key_expr\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x07keyExpr\x12\x33\n\x0bmaintainers\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x0bmaintainers\x1a\xaf\x01\n\nImplements\x12\x36\n\tinterface\x18\x01 \x01(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\tinterface\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32\".daml_lf_2_1.InterfaceInstanceBodyR\x04\x62ody\x12\x31\n\x08location\x18\x03 \x01(\x0b\x32\x15.daml_lf_2_1.LocationR\x08location\"\x9d\x01\n\x0fInterfaceMethod\x12\x31\n\x08location\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.LocationR\x08location\x12\x30\n\x14method_interned_name\x18\x02 \x01(\x05R\x12methodInternedName\x12%\n\x04type\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\"\xed\x02\n\x0c\x44\x65\x66Interface\x12\x31\n\x08location\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.LocationR\x08location\x12\x30\n\x14tycon_interned_dname\x18\x02 \x01(\x05R\x12tyconInternedDname\x12\x36\n\x07methods\x18\x03 \x03(\x0b\x32\x1c.daml_lf_2_1.InterfaceMethodR\x07methods\x12,\n\x12param_interned_str\x18\x04 \x01(\x05R\x10paramInternedStr\x12\x35\n\x07\x63hoices\x18\x05 \x03(\x0b\x32\x1b.daml_lf_2_1.TemplateChoiceR\x07\x63hoices\x12%\n\x04view\x18\x06 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04view\x12\x34\n\x08requires\x18\x07 \x03(\x0b\x32\x18.daml_lf_2_1.TypeConNameR\x08requires\"\x9e\x01\n\x0c\x44\x65\x66\x45xception\x12.\n\x13name_interned_dname\x18\x01 \x01(\x05R\x11nameInternedDname\x12\x31\n\x08location\x18\x02 \x01(\x0b\x32\x15.daml_lf_2_1.LocationR\x08location\x12+\n\x07message\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x07message\"\xd0\x04\n\x0b\x44\x65\x66\x44\x61taType\x12\x31\n\x08location\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.LocationR\x08location\x12.\n\x13name_interned_dname\x18\x02 \x01(\x05R\x11nameInternedDname\x12\x34\n\x06params\x18\x03 \x03(\x0b\x32\x1c.daml_lf_2_1.TypeVarWithKindR\x06params\x12\"\n\x0cserializable\x18\x04 \x01(\x08R\x0cserializable\x12\x39\n\x06record\x18\x05 \x01(\x0b\x32\x1f.daml_lf_2_1.DefDataType.FieldsH\x00R\x06record\x12;\n\x07variant\x18\x06 \x01(\x0b\x32\x1f.daml_lf_2_1.DefDataType.FieldsH\x00R\x07variant\x12?\n\x04\x65num\x18\x07 \x01(\x0b\x32).daml_lf_2_1.DefDataType.EnumConstructorsH\x00R\x04\x65num\x12\x31\n\tinterface\x18\x08 \x01(\x0b\x32\x11.daml_lf_2_1.UnitH\x00R\tinterface\x1a<\n\x06\x46ields\x12\x32\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x1a.daml_lf_2_1.FieldWithTypeR\x06\x66ields\x1aN\n\x10\x45numConstructors\x12:\n\x19\x63onstructors_interned_str\x18\x02 \x03(\x05R\x17\x63onstructorsInternedStrB\n\n\x08\x44\x61taCons\"\xcc\x01\n\nDefTypeSyn\x12\x31\n\x08location\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.LocationR\x08location\x12.\n\x13name_interned_dname\x18\x02 \x01(\x05R\x11nameInternedDname\x12\x34\n\x06params\x18\x03 \x03(\x0b\x32\x1c.daml_lf_2_1.TypeVarWithKindR\x06params\x12%\n\x04type\x18\x04 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\"\xaf\x02\n\x08\x44\x65\x66Value\x12\x31\n\x08location\x18\x01 \x01(\x0b\x32\x15.daml_lf_2_1.LocationR\x08location\x12H\n\x0ename_with_type\x18\x02 \x01(\x0b\x32\".daml_lf_2_1.DefValue.NameWithTypeR\x0cnameWithType\x12%\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x11.daml_lf_2_1.ExprR\x04\x65xpr\x12\x18\n\x07is_test\x18\xe8\x07 \x01(\x08R\x06isTest\x1a\x65\n\x0cNameWithType\x12.\n\x13name_interned_dname\x18\x01 \x01(\x05R\x11nameInternedDname\x12%\n\x04type\x18\x02 \x01(\x0b\x32\x11.daml_lf_2_1.TypeR\x04type\"\xfa\x01\n\x0c\x46\x65\x61tureFlags\x12\x30\n\x13\x66orbidPartyLiterals\x18\x01 \x01(\x08R\x13\x66orbidPartyLiterals\x12X\n\'dontDivulgeContractIdsInCreateArguments\x18\x02 \x01(\x08R\'dontDivulgeContractIdsInCreateArguments\x12^\n*dontDiscloseNonConsumingChoicesToObservers\x18\x03 \x01(\x08R*dontDiscloseNonConsumingChoicesToObservers\"\xb4\x03\n\x06Module\x12.\n\x13name_interned_dname\x18\x01 \x01(\x05R\x11nameInternedDname\x12/\n\x05\x66lags\x18\x02 \x01(\x0b\x32\x19.daml_lf_2_1.FeatureFlagsR\x05\x66lags\x12\x33\n\x08synonyms\x18\x03 \x03(\x0b\x32\x17.daml_lf_2_1.DefTypeSynR\x08synonyms\x12\x37\n\ndata_types\x18\x04 \x03(\x0b\x32\x18.daml_lf_2_1.DefDataTypeR\tdataTypes\x12-\n\x06values\x18\x05 \x03(\x0b\x32\x15.daml_lf_2_1.DefValueR\x06values\x12\x36\n\ttemplates\x18\x06 \x03(\x0b\x32\x18.daml_lf_2_1.DefTemplateR\ttemplates\x12\x39\n\nexceptions\x18\x07 \x03(\x0b\x32\x19.daml_lf_2_1.DefExceptionR\nexceptions\x12\x39\n\ninterfaces\x18\x08 \x03(\x0b\x32\x19.daml_lf_2_1.DefInterfaceR\ninterfaces\"H\n\x12InternedDottedName\x12\x32\n\x15segments_interned_str\x18\x01 \x03(\x05R\x13segmentsInternedStr\"[\n\x11UpgradedPackageId\x12\x46\n upgraded_package_id_interned_str\x18\x01 \x01(\x05R\x1cupgradedPackageIdInternedStr\"\xbf\x01\n\x0fPackageMetadata\x12*\n\x11name_interned_str\x18\x01 \x01(\x05R\x0fnameInternedStr\x12\x30\n\x14version_interned_str\x18\x02 \x01(\x05R\x12versionInternedStr\x12N\n\x13upgraded_package_id\x18\x03 \x01(\x0b\x32\x1e.daml_lf_2_1.UpgradedPackageIdR\x11upgradedPackageId\"\xac\x02\n\x07Package\x12-\n\x07modules\x18\x01 \x03(\x0b\x32\x13.daml_lf_2_1.ModuleR\x07modules\x12)\n\x10interned_strings\x18\x02 \x03(\tR\x0finternedStrings\x12S\n\x15interned_dotted_names\x18\x03 \x03(\x0b\x32\x1f.daml_lf_2_1.InternedDottedNameR\x13internedDottedNames\x12\x38\n\x08metadata\x18\x04 \x01(\x0b\x32\x1c.daml_lf_2_1.PackageMetadataR\x08metadata\x12\x38\n\x0einterned_types\x18\x05 \x03(\x0b\x32\x11.daml_lf_2_1.TypeR\rinternedTypes*\x9f\x02\n\x0b\x42uiltinType\x12\x08\n\x04UNIT\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\t\n\x05INT64\x10\x02\x12\x08\n\x04\x44\x41TE\x10\x03\x12\r\n\tTIMESTAMP\x10\x04\x12\x0b\n\x07NUMERIC\x10\x05\x12\t\n\x05PARTY\x10\x06\x12\x08\n\x04TEXT\x10\x07\x12\x0f\n\x0b\x43ONTRACT_ID\x10\x08\x12\x0c\n\x08OPTIONAL\x10\t\x12\x08\n\x04LIST\x10\n\x12\n\n\x06GENMAP\x10\x0b\x12\x07\n\x03\x41NY\x10\r\x12\x11\n\rANY_EXCEPTION\x10\x0e\x12\x0c\n\x08TYPE_REP\x10\x0f\x12\t\n\x05\x41RROW\x10\x10\x12\n\n\x06UPDATE\x10\x11\x12\x0c\n\x07TEXTMAP\x10\xe9\x07\x12\x0f\n\nBIGNUMERIC\x10\xea\x07\x12\x12\n\rROUNDING_MODE\x10\xeb\x07\x12\r\n\x08SCENARIO\x10\xec\x07*7\n\nBuiltinCon\x12\x0c\n\x08\x43ON_UNIT\x10\x00\x12\r\n\tCON_FALSE\x10\x01\x12\x0c\n\x08\x43ON_TRUE\x10\x02*\xf1\n\n\x0f\x42uiltinFunction\x12\t\n\x05TRACE\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\t\n\x05\x45QUAL\x10\x02\x12\x0b\n\x07LESS_EQ\x10\x03\x12\x08\n\x04LESS\x10\x04\x12\x0e\n\nGREATER_EQ\x10\x05\x12\x0b\n\x07GREATER\x10\x06\x12\r\n\tADD_INT64\x10\x07\x12\r\n\tSUB_INT64\x10\x08\x12\r\n\tMUL_INT64\x10\t\x12\r\n\tDIV_INT64\x10\n\x12\r\n\tMOD_INT64\x10\x0b\x12\r\n\tEXP_INT64\x10\x0c\x12\x0f\n\x0b\x41\x44\x44_NUMERIC\x10\r\x12\x0f\n\x0bSUB_NUMERIC\x10\x0e\x12\x0f\n\x0bMUL_NUMERIC\x10\x0f\x12\x0f\n\x0b\x44IV_NUMERIC\x10\x10\x12\x11\n\rROUND_NUMERIC\x10\x11\x12\x10\n\x0c\x43\x41ST_NUMERIC\x10\x12\x12\x11\n\rSHIFT_NUMERIC\x10\x13\x12\x14\n\x10INT64_TO_NUMERIC\x10\x14\x12\x14\n\x10NUMERIC_TO_INT64\x10\x15\x12\x11\n\rINT64_TO_TEXT\x10\x16\x12\x13\n\x0fNUMERIC_TO_TEXT\x10\x17\x12\x15\n\x11TIMESTAMP_TO_TEXT\x10\x19\x12\x10\n\x0c\x44\x41TE_TO_TEXT\x10\x1a\x12\x11\n\rPARTY_TO_TEXT\x10\x1b\x12\x11\n\rTEXT_TO_PARTY\x10\x1c\x12\x11\n\rTEXT_TO_INT64\x10\x1d\x12\x13\n\x0fTEXT_TO_NUMERIC\x10\x1e\x12\x17\n\x13\x43ONTRACT_ID_TO_TEXT\x10\x1f\x12\x0f\n\x0bSHA256_TEXT\x10 \x12\x10\n\x0c\x45XPLODE_TEXT\x10!\x12\x0f\n\x0b\x41PPEND_TEXT\x10\"\x12\x10\n\x0cIMPLODE_TEXT\x10#\x12\x17\n\x13\x43ODE_POINTS_TO_TEXT\x10$\x12\x17\n\x13TEXT_TO_CODE_POINTS\x10%\x12\x15\n\x11\x44\x41TE_TO_UNIX_DAYS\x10&\x12\x15\n\x11UNIX_DAYS_TO_DATE\x10\'\x12\"\n\x1eTIMESTAMP_TO_UNIX_MICROSECONDS\x10(\x12\"\n\x1eUNIX_MICROSECONDS_TO_TIMESTAMP\x10)\x12\x16\n\x12\x43OERCE_CONTRACT_ID\x10*\x12\t\n\x05\x46OLDL\x10+\x12\t\n\x05\x46OLDR\x10,\x12\x0e\n\nEQUAL_LIST\x10-\x12\x10\n\x0cGENMAP_EMPTY\x10\x34\x12\x11\n\rGENMAP_INSERT\x10\x35\x12\x11\n\rGENMAP_LOOKUP\x10\x36\x12\x11\n\rGENMAP_DELETE\x10\x37\x12\x0f\n\x0bGENMAP_KEYS\x10\x38\x12\x11\n\rGENMAP_VALUES\x10\x39\x12\x0f\n\x0bGENMAP_SIZE\x10:\x12\x19\n\x15\x41NY_EXCEPTION_MESSAGE\x10;\x12\x12\n\rTEXTMAP_EMPTY\x10\xe9\x07\x12\x13\n\x0eTEXTMAP_INSERT\x10\xea\x07\x12\x13\n\x0eTEXTMAP_LOOKUP\x10\xeb\x07\x12\x13\n\x0eTEXTMAP_DELETE\x10\xec\x07\x12\x14\n\x0fTEXTMAP_TO_LIST\x10\xed\x07\x12\x11\n\x0cTEXTMAP_SIZE\x10\xee\x07\x12\x15\n\x10SCALE_BIGNUMERIC\x10\xd1\x0f\x12\x19\n\x14PRECISION_BIGNUMERIC\x10\xd2\x0f\x12\x13\n\x0e\x41\x44\x44_BIGNUMERIC\x10\xd3\x0f\x12\x13\n\x0eSUB_BIGNUMERIC\x10\xd4\x0f\x12\x13\n\x0eMUL_BIGNUMERIC\x10\xd5\x0f\x12\x13\n\x0e\x44IV_BIGNUMERIC\x10\xd6\x0f\x12\x1b\n\x16SHIFT_RIGHT_BIGNUMERIC\x10\xd7\x0f\x12\x1a\n\x15\x42IGNUMERIC_TO_NUMERIC\x10\xd8\x0f\x12\x1a\n\x15NUMERIC_TO_BIGNUMERIC\x10\xd9\x0f\x12\x17\n\x12\x42IGNUMERIC_TO_TEXT\x10\xda\x0f\x12\x18\n\x13TYPE_REP_TYCON_NAME\x10\xc3\x17\x42z\n\x14\x63om.daml.daml_lf_2_1ZCgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/daml_lf_2_1\xaa\x02\x1c\x43om.Daml.Daml_Lf_2_1.DamlLf2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.daml_lf_2_1.daml_lf2_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.daml.daml_lf_2_1ZCgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/daml_lf_2_1\252\002\034Com.Daml.Daml_Lf_2_1.DamlLf2'
  _globals['_BUILTINTYPE']._serialized_start=20497
  _globals['_BUILTINTYPE']._serialized_end=20784
  _globals['_BUILTINCON']._serialized_start=20786
  _globals['_BUILTINCON']._serialized_end=20841
  _globals['_BUILTINFUNCTION']._serialized_start=20844
  _globals['_BUILTINFUNCTION']._serialized_end=22237
  _globals['_UNIT']._serialized_start=52
  _globals['_UNIT']._serialized_end=58
  _globals['_PACKAGEREF']._serialized_start=60
  _globals['_PACKAGEREF']._serialized_end=177
  _globals['_MODULEREF']._serialized_start=180
  _globals['_MODULEREF']._serialized_end=310
  _globals['_TYPECONNAME']._serialized_start=312
  _globals['_TYPECONNAME']._serialized_end=421
  _globals['_TYPESYNNAME']._serialized_start=423
  _globals['_TYPESYNNAME']._serialized_end=532
  _globals['_VALNAME']._serialized_start=534
  _globals['_VALNAME']._serialized_end=639
  _globals['_FIELDWITHTYPE']._serialized_start=641
  _globals['_FIELDWITHTYPE']._serialized_end=741
  _globals['_VARWITHTYPE']._serialized_start=743
  _globals['_VARWITHTYPE']._serialized_end=837
  _globals['_TYPEVARWITHKIND']._serialized_start=839
  _globals['_TYPEVARWITHKIND']._serialized_end=937
  _globals['_FIELDWITHEXPR']._serialized_start=939
  _globals['_FIELDWITHEXPR']._serialized_end=1039
  _globals['_BINDING']._serialized_start=1041
  _globals['_BINDING']._serialized_end=1141
  _globals['_KIND']._serialized_start=1144
  _globals['_KIND']._serialized_end=1381
  _globals['_KIND_ARROW']._serialized_start=1281
  _globals['_KIND_ARROW']._serialized_end=1374
  _globals['_TYPE']._serialized_start=1384
  _globals['_TYPE']._serialized_end=2274
  _globals['_TYPE_VAR']._serialized_start=1730
  _globals['_TYPE_VAR']._serialized_end=1816
  _globals['_TYPE_CON']._serialized_start=1818
  _globals['_TYPE_CON']._serialized_end=1910
  _globals['_TYPE_SYN']._serialized_start=1912
  _globals['_TYPE_SYN']._serialized_end=2004
  _globals['_TYPE_BUILTIN']._serialized_start=2006
  _globals['_TYPE_BUILTIN']._serialized_end=2106
  _globals['_TYPE_FORALL']._serialized_start=2108
  _globals['_TYPE_FORALL']._serialized_end=2205
  _globals['_TYPE_STRUCT']._serialized_start=2207
  _globals['_TYPE_STRUCT']._serialized_end=2267
  _globals['_BUILTINLIT']._serialized_start=2277
  _globals['_BUILTINLIT']._serialized_end=2668
  _globals['_BUILTINLIT_ROUNDINGMODE']._serialized_start=2545
  _globals['_BUILTINLIT_ROUNDINGMODE']._serialized_end=2661
  _globals['_LOCATION']._serialized_start=2671
  _globals['_LOCATION']._serialized_end=2901
  _globals['_LOCATION_RANGE']._serialized_start=2782
  _globals['_LOCATION_RANGE']._serialized_end=2901
  _globals['_EXPR']._serialized_start=2904
  _globals['_EXPR']._serialized_end=10756
  _globals['_EXPR_RECCON']._serialized_start=5873
  _globals['_EXPR_RECCON']._serialized_end=5978
  _globals['_EXPR_RECPROJ']._serialized_start=5981
  _globals['_EXPR_RECPROJ']._serialized_end=6124
  _globals['_EXPR_RECUPD']._serialized_start=6127
  _globals['_EXPR_RECUPD']._serialized_end=6312
  _globals['_EXPR_VARIANTCON']._serialized_start=6315
  _globals['_EXPR_VARIANTCON']._serialized_end=6481
  _globals['_EXPR_ENUMCON']._serialized_start=6483
  _globals['_EXPR_ENUMCON']._serialized_end=6591
  _globals['_EXPR_STRUCTCON']._serialized_start=6593
  _globals['_EXPR_STRUCTCON']._serialized_end=6656
  _globals['_EXPR_STRUCTPROJ']._serialized_start=6658
  _globals['_EXPR_STRUCTPROJ']._serialized_end=6759
  _globals['_EXPR_STRUCTUPD']._serialized_start=6762
  _globals['_EXPR_STRUCTUPD']._serialized_end=6905
  _globals['_EXPR_APP']._serialized_start=6907
  _globals['_EXPR_APP']._serialized_end=6988
  _globals['_EXPR_TYAPP']._serialized_start=6990
  _globals['_EXPR_TYAPP']._serialized_end=7077
  _globals['_EXPR_ABS']._serialized_start=7079
  _globals['_EXPR_ABS']._serialized_end=7171
  _globals['_EXPR_TYABS']._serialized_start=7173
  _globals['_EXPR_TYABS']._serialized_end=7271
  _globals['_EXPR_NIL']._serialized_start=7273
  _globals['_EXPR_NIL']._serialized_end=7317
  _globals['_EXPR_CONS']._serialized_start=7319
  _globals['_EXPR_CONS']._serialized_end=7444
  _globals['_EXPR_OPTIONALNONE']._serialized_start=7446
  _globals['_EXPR_OPTIONALNONE']._serialized_end=7499
  _globals['_EXPR_OPTIONALSOME']._serialized_start=7501
  _globals['_EXPR_OPTIONALSOME']._serialized_end=7595
  _globals['_EXPR_TOANY']._serialized_start=7597
  _globals['_EXPR_TOANY']._serialized_end=7682
  _globals['_EXPR_FROMANY']._serialized_start=7684
  _globals['_EXPR_FROMANY']._serialized_end=7771
  _globals['_EXPR_TOANYEXCEPTION']._serialized_start=7773
  _globals['_EXPR_TOANYEXCEPTION']._serialized_end=7867
  _globals['_EXPR_FROMANYEXCEPTION']._serialized_start=7869
  _globals['_EXPR_FROMANYEXCEPTION']._serialized_end=7965
  _globals['_EXPR_THROW']._serialized_start=7968
  _globals['_EXPR_THROW']._serialized_end=8143
  _globals['_EXPR_TOINTERFACE']._serialized_start=8146
  _globals['_EXPR_TOINTERFACE']._serialized_end=8343
  _globals['_EXPR_FROMINTERFACE']._serialized_start=8346
  _globals['_EXPR_FROMINTERFACE']._serialized_end=8547
  _globals['_EXPR_CALLINTERFACE']._serialized_start=8550
  _globals['_EXPR_CALLINTERFACE']._serialized_end=8738
  _globals['_EXPR_VIEWINTERFACE']._serialized_start=8740
  _globals['_EXPR_VIEWINTERFACE']._serialized_end=8850
  _globals['_EXPR_SIGNATORYINTERFACE']._serialized_start=8852
  _globals['_EXPR_SIGNATORYINTERFACE']._serialized_end=8967
  _globals['_EXPR_OBSERVERINTERFACE']._serialized_start=8969
  _globals['_EXPR_OBSERVERINTERFACE']._serialized_end=9083
  _globals['_EXPR_UNSAFEFROMINTERFACE']._serialized_start=9086
  _globals['_EXPR_UNSAFEFROMINTERFACE']._serialized_end=9354
  _globals['_EXPR_TOREQUIREDINTERFACE']._serialized_start=9357
  _globals['_EXPR_TOREQUIREDINTERFACE']._serialized_end=9565
  _globals['_EXPR_FROMREQUIREDINTERFACE']._serialized_start=9568
  _globals['_EXPR_FROMREQUIREDINTERFACE']._serialized_end=9778
  _globals['_EXPR_UNSAFEFROMREQUIREDINTERFACE']._serialized_start=9781
  _globals['_EXPR_UNSAFEFROMREQUIREDINTERFACE']._serialized_end=10077
  _globals['_EXPR_INTERFACETEMPLATETYPEREP']._serialized_start=10079
  _globals['_EXPR_INTERFACETEMPLATETYPEREP']._serialized_end=10200
  _globals['_EXPR_CHOICECONTROLLER']._serialized_start=10203
  _globals['_EXPR_CHOICECONTROLLER']._serialized_end=10438
  _globals['_EXPR_CHOICEOBSERVER']._serialized_start=10441
  _globals['_EXPR_CHOICEOBSERVER']._serialized_end=10674
  _globals['_EXPR_EXPERIMENTAL']._serialized_start=10676
  _globals['_EXPR_EXPERIMENTAL']._serialized_end=10749
  _globals['_CASEALT']._serialized_start=10759
  _globals['_CASEALT']._serialized_end=11689
  _globals['_CASEALT_VARIANT']._serialized_start=11244
  _globals['_CASEALT_VARIANT']._serialized_end=11395
  _globals['_CASEALT_ENUM']._serialized_start=11397
  _globals['_CASEALT_ENUM']._serialized_end=11505
  _globals['_CASEALT_CONS']._serialized_start=11507
  _globals['_CASEALT_CONS']._serialized_end=11615
  _globals['_CASEALT_OPTIONALSOME']._serialized_start=11617
  _globals['_CASEALT_OPTIONALSOME']._serialized_end=11682
  _globals['_CASE']._serialized_start=11691
  _globals['_CASE']._serialized_end=11780
  _globals['_BLOCK']._serialized_start=11782
  _globals['_BLOCK']._serialized_end=11878
  _globals['_PURE']._serialized_start=11880
  _globals['_PURE']._serialized_end=11964
  _globals['_UPDATE']._serialized_start=11967
  _globals['_UPDATE']._serialized_end=15050
  _globals['_UPDATE_CREATE']._serialized_start=13092
  _globals['_UPDATE_CREATE']._serialized_end=13193
  _globals['_UPDATE_CREATEINTERFACE']._serialized_start=13195
  _globals['_UPDATE_CREATEINTERFACE']._serialized_end=13307
  _globals['_UPDATE_EXERCISE']._serialized_start=13310
  _globals['_UPDATE_EXERCISE']._serialized_end=13502
  _globals['_UPDATE_SOFTEXERCISE']._serialized_start=13505
  _globals['_UPDATE_SOFTEXERCISE']._serialized_end=13695
  _globals['_UPDATE_DYNAMICEXERCISE']._serialized_start=13698
  _globals['_UPDATE_DYNAMICEXERCISE']._serialized_end=13891
  _globals['_UPDATE_EXERCISEINTERFACE']._serialized_start=13894
  _globals['_UPDATE_EXERCISEINTERFACE']._serialized_end=14132
  _globals['_UPDATE_EXERCISEBYKEY']._serialized_start=14135
  _globals['_UPDATE_EXERCISEBYKEY']._serialized_end=14326
  _globals['_UPDATE_FETCH']._serialized_start=14328
  _globals['_UPDATE_FETCH']._serialized_end=14426
  _globals['_UPDATE_SOFTFETCH']._serialized_start=14428
  _globals['_UPDATE_SOFTFETCH']._serialized_end=14530
  _globals['_UPDATE_FETCHINTERFACE']._serialized_start=14532
  _globals['_UPDATE_FETCHINTERFACE']._serialized_end=14641
  _globals['_UPDATE_EMBEDEXPR']._serialized_start=14643
  _globals['_UPDATE_EMBEDEXPR']._serialized_end=14732
  _globals['_UPDATE_RETRIEVEBYKEY']._serialized_start=14734
  _globals['_UPDATE_RETRIEVEBYKEY']._serialized_end=14840
  _globals['_UPDATE_TRYCATCH']._serialized_start=14843
  _globals['_UPDATE_TRYCATCH']._serialized_end=15043
  _globals['_SCENARIO']._serialized_start=15053
  _globals['_SCENARIO']._serialized_end=15708
  _globals['_SCENARIO_COMMIT']._serialized_start=15476
  _globals['_SCENARIO_COMMIT']._serialized_end=15610
  _globals['_SCENARIO_EMBEDEXPR']._serialized_start=14643
  _globals['_SCENARIO_EMBEDEXPR']._serialized_end=14732
  _globals['_TEMPLATECHOICE']._serialized_start=15711
  _globals['_TEMPLATECHOICE']._serialized_end=16211
  _globals['_INTERFACEINSTANCEBODY']._serialized_start=16214
  _globals['_INTERFACEINSTANCEBODY']._serialized_end=16480
  _globals['_INTERFACEINSTANCEBODY_INTERFACEINSTANCEMETHOD']._serialized_start=16364
  _globals['_INTERFACEINSTANCEBODY_INTERFACEINSTANCEMETHOD']._serialized_end=16480
  _globals['_DEFTEMPLATE']._serialized_start=16483
  _globals['_DEFTEMPLATE']._serialized_end=17341
  _globals['_DEFTEMPLATE_DEFKEY']._serialized_start=17017
  _globals['_DEFTEMPLATE_DEFKEY']._serialized_end=17163
  _globals['_DEFTEMPLATE_IMPLEMENTS']._serialized_start=17166
  _globals['_DEFTEMPLATE_IMPLEMENTS']._serialized_end=17341
  _globals['_INTERFACEMETHOD']._serialized_start=17344
  _globals['_INTERFACEMETHOD']._serialized_end=17501
  _globals['_DEFINTERFACE']._serialized_start=17504
  _globals['_DEFINTERFACE']._serialized_end=17869
  _globals['_DEFEXCEPTION']._serialized_start=17872
  _globals['_DEFEXCEPTION']._serialized_end=18030
  _globals['_DEFDATATYPE']._serialized_start=18033
  _globals['_DEFDATATYPE']._serialized_end=18625
  _globals['_DEFDATATYPE_FIELDS']._serialized_start=18473
  _globals['_DEFDATATYPE_FIELDS']._serialized_end=18533
  _globals['_DEFDATATYPE_ENUMCONSTRUCTORS']._serialized_start=18535
  _globals['_DEFDATATYPE_ENUMCONSTRUCTORS']._serialized_end=18613
  _globals['_DEFTYPESYN']._serialized_start=18628
  _globals['_DEFTYPESYN']._serialized_end=18832
  _globals['_DEFVALUE']._serialized_start=18835
  _globals['_DEFVALUE']._serialized_end=19138
  _globals['_DEFVALUE_NAMEWITHTYPE']._serialized_start=19037
  _globals['_DEFVALUE_NAMEWITHTYPE']._serialized_end=19138
  _globals['_FEATUREFLAGS']._serialized_start=19141
  _globals['_FEATUREFLAGS']._serialized_end=19391
  _globals['_MODULE']._serialized_start=19394
  _globals['_MODULE']._serialized_end=19830
  _globals['_INTERNEDDOTTEDNAME']._serialized_start=19832
  _globals['_INTERNEDDOTTEDNAME']._serialized_end=19904
  _globals['_UPGRADEDPACKAGEID']._serialized_start=19906
  _globals['_UPGRADEDPACKAGEID']._serialized_end=19997
  _globals['_PACKAGEMETADATA']._serialized_start=20000
  _globals['_PACKAGEMETADATA']._serialized_end=20191
  _globals['_PACKAGE']._serialized_start=20194
  _globals['_PACKAGE']._serialized_end=20494
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from ....admin.pruning.v30.pruning_pb2 import ClearScheduleRequest, ClearScheduleResponse, GetScheduleRequest, GetScheduleResponse, LocatePruningTimestampRequest, LocatePruningTimestampResponse, SetCronRequest, SetCronResponse, SetMaxDurationRequest, SetMaxDurationResponse, SetRetentionRequest, SetRetentionResponse, SetScheduleRequest, SetScheduleResponse
from .mediator_administration_service_pb2 import MediatorPruning

__all__ = [
    "MediatorAdministrationServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class MediatorAdministrationServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _MediatorAdministrationServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _MediatorAdministrationServiceAsyncStub: ...  # type: ignore
    def Prune(self, __1: MediatorPruning.PruneRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[MediatorPruning.PruneResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, MediatorPruning.PruneResponse]]: ...
    def SetSchedule(self, __1: SetScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetScheduleResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SetScheduleResponse]]: ...
    def SetCron(self, __1: SetCronRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetCronResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SetCronResponse]]: ...
    def SetMaxDuration(self, __1: SetMaxDurationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetMaxDurationResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SetMaxDurationResponse]]: ...
    def SetRetention(self, __1: SetRetentionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetRetentionResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SetRetentionResponse]]: ...
    def ClearSchedule(self, __1: ClearScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ClearScheduleResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ClearScheduleResponse]]: ...
    def GetSchedule(self, __1: GetScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetScheduleResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetScheduleResponse]]: ...
    def LocatePruningTimestamp(self, __1: LocatePruningTimestampRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[LocatePruningTimestampResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, LocatePruningTimestampResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _MediatorAdministrationServiceBlockingStub(MediatorAdministrationServiceStub):
    def Prune(self, __1: MediatorPruning.PruneRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> MediatorPruning.PruneResponse: ...
    def SetSchedule(self, __1: SetScheduleRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetScheduleResponse: ...
    def SetCron(self, __1: SetCronRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetCronResponse: ...
    def SetMaxDuration(self, __1: SetMaxDurationRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetMaxDurationResponse: ...
    def SetRetention(self, __1: SetRetentionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetRetentionResponse: ...
    def ClearSchedule(self, __1: ClearScheduleRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ClearScheduleResponse: ...
    def GetSchedule(self, __1: GetScheduleRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetScheduleResponse: ...
    def LocatePruningTimestamp(self, __1: LocatePruningTimestampRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LocatePruningTimestampResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _MediatorAdministrationServiceAsyncStub(MediatorAdministrationServiceStub):
    def Prune(self, __1: MediatorPruning.PruneRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, MediatorPruning.PruneResponse]: ...  # type: ignore
    def SetSchedule(self, __1: SetScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetScheduleResponse]: ...  # type: ignore
    def SetCron(self, __1: SetCronRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetCronResponse]: ...  # type: ignore
    def SetMaxDuration(self, __1: SetMaxDurationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetMaxDurationResponse]: ...  # type: ignore
    def SetRetention(self, __1: SetRetentionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetRetentionResponse]: ...  # type: ignore
    def ClearSchedule(self, __1: ClearScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ClearScheduleResponse]: ...  # type: ignore
    def GetSchedule(self, __1: GetScheduleRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetScheduleResponse]: ...  # type: ignore
    def LocatePruningTimestamp(self, __1: LocatePruningTimestampRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LocatePruningTimestampResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v0/mediator_response.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/protocol/v0/mediator_response.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;com/digitalasset/canton/protocol/v0/mediator_response.proto\x12#com.digitalasset.canton.protocol.v0\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc3\x02\n\x10MediatorResponse\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12\x1b\n\tview_hash\x18\x03 \x01(\x0cR\x08viewHash\x12V\n\rlocal_verdict\x18\x04 \x01(\x0b\x32\x31.com.digitalasset.canton.protocol.v0.LocalVerdictR\x0clocalVerdict\x12\x1b\n\troot_hash\x18\x05 \x01(\x0cR\x08rootHash\x12-\n\x12\x63onfirming_parties\x18\x06 \x03(\tR\x11\x63onfirmingParties\x12\x1b\n\tdomain_id\x18\x07 \x01(\tR\x08\x64omainId\"\xba\x01\n\x0cLocalVerdict\x12=\n\rlocal_approve\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x0clocalApprove\x12U\n\x0clocal_reject\x18\x02 \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v0.LocalRejectH\x00R\x0blocalRejectB\x14\n\x12some_local_verdict\"\xd2\x04\n\x0bLocalReject\x12I\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x35.com.digitalasset.canton.protocol.v0.LocalReject.CodeR\x04\x63ode\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\x12\x1a\n\x08resource\x18\x03 \x03(\tR\x08resource\"\xc3\x03\n\x04\x43ode\x12\x0f\n\x0bMissingCode\x10\x00\x12\x13\n\x0fLockedContracts\x10\x01\x12\x0e\n\nLockedKeys\x10\x02\x12\x15\n\x11InactiveContracts\x10\x03\x12\x10\n\x0c\x44uplicateKey\x10\x04\x12\x1b\n\x17\x43reatesExistingContract\x10\x05\x12\x0e\n\nLedgerTime\x10\x06\x12\x12\n\x0eSubmissionTime\x10\x07\x12\x10\n\x0cLocalTimeout\x10\x08\x12\x15\n\x11MalformedPayloads\x10\t\x12\x12\n\x0eMalformedModel\x10\n\x12\x1f\n\x1bMalformedConfirmationPolicy\x10\x0b\x12\x16\n\x12\x42\x61\x64RootHashMessage\x10\x0c\x12\x1e\n\x1aTransferOutActivenessCheck\x10\r\x12\x1e\n\x1aTransferInAlreadyCompleted\x10\x0e\x12\x1b\n\x17TransferInAlreadyActive\x10\x0f\x12\x1d\n\x19TransferInAlreadyArchived\x10\x10\x12\x14\n\x10TransferInLocked\x10\x11\x12\x13\n\x0fInconsistentKey\x10\x12\x42TZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v0.mediator_response_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0'
  _globals['_MEDIATORRESPONSE']._serialized_start=163
  _globals['_MEDIATORRESPONSE']._serialized_end=486
  _globals['_LOCALVERDICT']._serialized_start=489
  _globals['_LOCALVERDICT']._serialized_end=675
  _globals['_LOCALREJECT']._serialized_start=678
  _globals['_LOCALREJECT']._serialized_end=1272
  _globals['_LOCALREJECT_CODE']._serialized_start=821
  _globals['_LOCALREJECT_CODE']._serialized_end=1272
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.rpc import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VersionedStatus(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _status_pb2.Status
    def __init__(self, status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/party/v30/party_replication.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'com/digitalasset/canton/participant/admin/party/v30/party_replication.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....admin.participant.v30 import active_contract_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_active__contract__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKcom/digitalasset/canton/participant/admin/party/v30/party_replication.proto\x12\x33\x63om.digitalasset.canton.participant.admin.party.v30\x1a\x43\x63om/digitalasset/canton/admin/participant/v30/active_contract.proto\">\n\x1bPartyReplicationInstruction\x12\x1f\n\x0bmax_counter\x18\x01 \x01(\rR\nmaxCounter\"\x93\x05\n\x1dPartyReplicationSourceMessage\x12z\n\tacs_chunk\x18\x01 \x01(\x0b\x32[.com.digitalasset.canton.participant.admin.party.v30.PartyReplicationSourceMessage.AcsChunkH\x00R\x08\x61\x63sChunk\x12\xac\x01\n\x1bsource_participant_is_ready\x18\x02 \x01(\x0b\x32k.com.digitalasset.canton.participant.admin.party.v30.PartyReplicationSourceMessage.SourceParticipantIsReadyH\x00R\x18sourceParticipantIsReady\x12{\n\nend_of_acs\x18\x03 \x01(\x0b\x32[.com.digitalasset.canton.participant.admin.party.v30.PartyReplicationSourceMessage.EndOfACSH\x00R\x08\x65ndOfAcs\x1a\x8f\x01\n\x08\x41\x63sChunk\x12#\n\rchunk_counter\x18\x01 \x01(\rR\x0c\x63hunkCounter\x12^\n\tcontracts\x18\x02 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.ActiveContractOldR\tcontracts\x1a\x1a\n\x18SourceParticipantIsReady\x1a\n\n\x08\x45ndOfACSB\x10\n\x0e\x64\x61ta_or_statusBdZbgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/party/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.party.v30.party_replication_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Zbgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/party/v30'
  _globals['_PARTYREPLICATIONINSTRUCTION']._serialized_start=201
  _globals['_PARTYREPLICATIONINSTRUCTION']._serialized_end=263
  _globals['_PARTYREPLICATIONSOURCEMESSAGE']._serialized_start=266
  _globals['_PARTYREPLICATIONSOURCEMESSAGE']._serialized_end=925
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_ACSCHUNK']._serialized_start=724
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_ACSCHUNK']._serialized_end=867
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_SOURCEPARTICIPANTISREADY']._serialized_start=869
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_SOURCEPARTICIPANTISREADY']._serialized_end=895
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_ENDOFACS']._serialized_start=897
  _globals['_PARTYREPLICATIONSOURCEMESSAGE_ENDOFACS']._serialized_end=907
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.created_event import CreatedEvent


T = TypeVar("T", bound="JsActiveContract")


@_attrs_define
class JsActiveContract:
    """
    Attributes:
        created_event (CreatedEvent): Records that a contract has been created, and choices may now be exercised on it.
        synchronizer_id (str): A valid synchronizer id
            Required
        reassignment_counter (int): Each corresponding assigned and unassigned event has the same reassignment_counter.
            This strictly increases
            with each unassign command for the same contract. Creation of the contract corresponds to reassignment_counter
            equals zero.
            This field will be the reassignment_counter of the latest observable activation event on this synchronizer,
            which is
            before the active_at_offset.
            Required
    """

    created_event: CreatedEvent
    synchronizer_id: str
    reassignment_counter: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        created_event = self.created_event.to_dict()

        synchronizer_id = self.synchronizer_id

        reassignment_counter = self.reassignment_counter

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "createdEvent": created_event,
                "synchronizerId": synchronizer_id,
                "reassignmentCounter": reassignment_counter,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.created_event import CreatedEvent

        d = dict(src_dict)
        created_event = CreatedEvent.from_dict(d.pop("createdEvent"))

        synchronizer_id = d.pop("synchronizerId")

        reassignment_counter = d.pop("reassignmentCounter")

        js_active_contract = cls(
            created_event=created_event,
            synchronizer_id=synchronizer_id,
            reassignment_counter=reassignment_counter,
        )

        js_active_contract.additional_properties = d
        return js_active_contract

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.js_archived import JsArchived
    from ..models.js_created import JsCreated


T = TypeVar("T", bound="JsGetEventsByContractIdResponse")


@_attrs_define
class JsGetEventsByContractIdResponse:
    """
    Attributes:
        created (JsCreated | Unset):
        archived (JsArchived | Unset):
    """

    created: JsCreated | Unset = UNSET
    archived: JsArchived | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        created: dict[str, Any] | Unset = UNSET
        if not isinstance(self.created, Unset):
            created = self.created.to_dict()

        archived: dict[str, Any] | Unset = UNSET
        if not isinstance(self.archived, Unset):
            archived = self.archived.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if created is not UNSET:
            field_dict["created"] = created
        if archived is not UNSET:
            field_dict["archived"] = archived

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.js_archived import JsArchived
        from ..models.js_created import JsCreated

        d = dict(src_dict)
        _created = d.pop("created", UNSET)
        created: JsCreated | Unset
        if isinstance(_created, Unset):
            created = UNSET
        else:
            created = JsCreated.from_dict(_created)

        _archived = d.pop("archived", UNSET)
        archived: JsArchived | Unset
        if isinstance(_archived, Unset):
            archived = UNSET
        else:
            archived = JsArchived.from_dict(_archived)

        js_get_events_by_contract_id_response = cls(
            created=created,
            archived=archived,
        )

        js_get_events_by_contract_id_response.additional_properties = d
        return js_get_events_by_contract_id_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="ExecuteSubmissionAndWaitResponse")


@_attrs_define
class ExecuteSubmissionAndWaitResponse:
    """
    Attributes:
        update_id (str): The id of the transaction that resulted from the submitted command.
            Must be a valid LedgerString (as described in ``value.proto``).
            Required
        completion_offset (int): The details of the offset field are described in ``community/ledger-api/README.md``.
            Required
    """

    update_id: str
    completion_offset: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        update_id = self.update_id

        completion_offset = self.completion_offset

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "updateId": update_id,
                "completionOffset": completion_offset,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        update_id = d.pop("updateId")

        completion_offset = d.pop("completionOffset")

        execute_submission_and_wait_response = cls(
            update_id=update_id,
            completion_offset=completion_offset,
        )

        execute_submission_and_wait_response.additional_properties = d
        return execute_submission_and_wait_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
